
From: Dominik Brodowski <linux@dominikbrodowski.net>

drivers/pci/setup-bus.c enumerates the CardBus windows (bus->resources[])

Signed-off-by: Dominik Brodowski <linux@dominikbrodowski.net>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 dev/null                      |    0 
 drivers/pcmcia/yenta_socket.c |   24 +++++++++++++-----------
 2 files changed, 13 insertions(+), 11 deletions(-)

diff -L x -puN /dev/null /dev/null
diff -puN drivers/pcmcia/yenta_socket.c~yenta-same-resources-in-same-structs drivers/pcmcia/yenta_socket.c
--- 25/drivers/pcmcia/yenta_socket.c~yenta-same-resources-in-same-structs	Mon Jul 11 17:25:45 2005
+++ 25-akpm/drivers/pcmcia/yenta_socket.c	Mon Jul 11 17:25:45 2005
@@ -603,13 +603,12 @@ static int yenta_sock_suspend(struct pcm
 #define PCIBIOS_MIN_CARDBUS_IO PCIBIOS_MIN_IO
 #endif
 
-static void yenta_allocate_res(struct yenta_socket *socket, int nr, unsigned type)
+static void yenta_allocate_res(struct yenta_socket *socket, int nr, unsigned type, int addr_start, int addr_end)
 {
 	struct pci_bus *bus;
 	struct resource *root, *res;
 	u32 start, end;
 	u32 align, size, min;
-	unsigned offset;
 	unsigned mask;
 
 	res = socket->dev->resource + PCI_BRIDGE_RESOURCES + nr;
@@ -622,13 +621,12 @@ static void yenta_allocate_res(struct ye
 	if (type & IORESOURCE_IO)
 		mask = ~3;
 
-	offset = 0x1c + 8*nr;
 	bus = socket->dev->subordinate;
 	res->name = bus->name;
 	res->flags = type;
 
-	start = config_readl(socket, offset) & mask;
-	end = config_readl(socket, offset+4) | ~mask;
+	start = config_readl(socket, addr_start) & mask;
+	end = config_readl(socket, addr_end) | ~mask;
 	if (start && end > start && !override_bios) {
 		res->start = start;
 		res->end = end;
@@ -671,8 +669,8 @@ static void yenta_allocate_res(struct ye
 	
 	do {
 		if (allocate_resource(root, res, size, start, end, align, NULL, NULL)==0) {
-			config_writel(socket, offset, res->start);
-			config_writel(socket, offset+4, res->end);
+			config_writel(socket, addr_start, res->start);
+			config_writel(socket, addr_end, res->end);
 			return;
 		}
 		size = size/2;
@@ -688,10 +686,14 @@ static void yenta_allocate_res(struct ye
  */
 static void yenta_allocate_resources(struct yenta_socket *socket)
 {
-	yenta_allocate_res(socket, 0, IORESOURCE_MEM|IORESOURCE_PREFETCH);
-	yenta_allocate_res(socket, 1, IORESOURCE_MEM);
-	yenta_allocate_res(socket, 2, IORESOURCE_IO);
-	yenta_allocate_res(socket, 3, IORESOURCE_IO);
+	yenta_allocate_res(socket, 0, IORESOURCE_IO,
+			   PCI_CB_IO_BASE_0, PCI_CB_IO_LIMIT_0);
+	yenta_allocate_res(socket, 1, IORESOURCE_IO,
+			   PCI_CB_IO_BASE_1, PCI_CB_IO_LIMIT_1);
+	yenta_allocate_res(socket, 2, IORESOURCE_MEM|IORESOURCE_PREFETCH,
+			   PCI_CB_MEMORY_BASE_0, PCI_CB_MEMORY_LIMIT_0);
+	yenta_allocate_res(socket, 3, IORESOURCE_MEM,
+			   PCI_CB_MEMORY_BASE_1, PCI_CB_MEMORY_LIMIT_1);
 }
 
 
_
